@@ -1,4 +1,11 @@
-#[cfg(test)]
+#![allow(missing_docs, reason = "okay in tests")]
+#![expect(
+    unused_crate_dependencies,
+    clippy::unwrap_used,
+    reason = "okay in tests"
+)]
+
+#[cfg(all(test, not(miri)))]
 #[test]
 fn test_readme_sync() {
     use readme_sync::{assert_sync, CMarkDocs, CMarkReadme, Config, Package};
